==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/WorkbookTemplateLocalizedGalleryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Localized template data and gallery information.
 * @property galleries Workbook galleries supported by the template.
 * @property templateData Valid JSON object containing workbook template payload.
 */
public data class WorkbookTemplateLocalizedGalleryArgs(
    public val galleries: Output<List<WorkbookTemplateGalleryArgs>>? = null,
    public val templateData: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs =
        com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs.builder()
            .galleries(
                galleries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .templateData(templateData?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkbookTemplateLocalizedGalleryArgs].
 */
@PulumiTagMarker
public class WorkbookTemplateLocalizedGalleryArgsBuilder internal constructor() {
    private var galleries: Output<List<WorkbookTemplateGalleryArgs>>? = null

    private var templateData: Output<Any>? = null

    /**
     * @param value Workbook galleries supported by the template.
     */
    @JvmName("xvfnidcvjwuyumxt")
    public suspend fun galleries(`value`: Output<List<WorkbookTemplateGalleryArgs>>) {
        this.galleries = value
    }

    @JvmName("ypxlvjnuahcyeaid")
    public suspend fun galleries(vararg values: Output<WorkbookTemplateGalleryArgs>) {
        this.galleries = Output.all(values.asList())
    }

    /**
     * @param values Workbook galleries supported by the template.
     */
    @JvmName("gsptkilgtvchpoya")
    public suspend fun galleries(values: List<Output<WorkbookTemplateGalleryArgs>>) {
        this.galleries = Output.all(values)
    }

    /**
     * @param value Valid JSON object containing workbook template payload.
     */
    @JvmName("pjqllrpjgceseiif")
    public suspend fun templateData(`value`: Output<Any>) {
        this.templateData = value
    }

    /**
     * @param value Workbook galleries supported by the template.
     */
    @JvmName("gvsrnlobelqohkqi")
    public suspend fun galleries(`value`: List<WorkbookTemplateGalleryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.galleries = mapped
    }

    /**
     * @param argument Workbook galleries supported by the template.
     */
    @JvmName("kpingijrvfeltqst")
    public suspend
    fun galleries(argument: List<suspend WorkbookTemplateGalleryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WorkbookTemplateGalleryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.galleries = mapped
    }

    /**
     * @param argument Workbook galleries supported by the template.
     */
    @JvmName("rfqqkvhujngulrco")
    public suspend fun galleries(
        vararg
        argument: suspend WorkbookTemplateGalleryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            WorkbookTemplateGalleryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.galleries = mapped
    }

    /**
     * @param argument Workbook galleries supported by the template.
     */
    @JvmName("kmuxakcqfduedyha")
    public suspend fun galleries(argument: suspend WorkbookTemplateGalleryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            WorkbookTemplateGalleryArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.galleries = mapped
    }

    /**
     * @param values Workbook galleries supported by the template.
     */
    @JvmName("yuygvsmschmhceau")
    public suspend fun galleries(vararg values: WorkbookTemplateGalleryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.galleries = mapped
    }

    /**
     * @param value Valid JSON object containing workbook template payload.
     */
    @JvmName("xluyyixqdfsjhdsv")
    public suspend fun templateData(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.templateData = mapped
    }

    internal fun build(): WorkbookTemplateLocalizedGalleryArgs = WorkbookTemplateLocalizedGalleryArgs(
        galleries = galleries,
        templateData = templateData,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/WorkbookTemplateLocalizedGalleryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Localized template data and gallery information.
 * @property galleries Workbook galleries supported by the template.
 * @property templateData Valid JSON object containing workbook template payload.
 */
public data class WorkbookTemplateLocalizedGalleryArgs(
    public val galleries: Output<List<WorkbookTemplateGalleryArgs>>? = null,
    public val templateData: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs =
        com.pulumi.azurenative.insights.inputs.WorkbookTemplateLocalizedGalleryArgs.builder()
            .galleries(
                galleries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .templateData(templateData?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkbookTemplateLocalizedGalleryArgs].
 */
@PulumiTagMarker
public class WorkbookTemplateLocalizedGalleryArgsBuilder internal constructor() {
    private var galleries: Output<List<WorkbookTemplateGalleryArgs>>? = null

    private var templateData: Output<Any>? = null

    /**
     * @param value Workbook galleries supported by the template.
     */
    @JvmName("gjhcgrpxfoflylva")
    public suspend fun galleries(`value`: Output<List<WorkbookTemplateGalleryArgs>>) {
        this.galleries = value
    }

    @JvmName("qpqpoboqkqyleiql")
    public suspend fun galleries(vararg values: Output<WorkbookTemplateGalleryArgs>) {
        this.galleries = Output.all(values.asList())
    }

    /**
     * @param values Workbook galleries supported by the template.
     */
    @JvmName("ievyrmbjqabwysnc")
    public suspend fun galleries(values: List<Output<WorkbookTemplateGalleryArgs>>) {
        this.galleries = Output.all(values)
    }

    /**
     * @param value Valid JSON object containing workbook template payload.
     */
    @JvmName("ljavqxcovphbulop")
    public suspend fun templateData(`value`: Output<Any>) {
        this.templateData = value
    }

    /**
     * @param value Workbook galleries supported by the template.
     */
    @JvmName("adqbeegxfbrwajwa")
    public suspend fun galleries(`value`: List<WorkbookTemplateGalleryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.galleries = mapped
    }

    /**
     * @param argument Workbook galleries supported by the template.
     */
    @JvmName("nxpqywcbdkhxiihn")
    public suspend
    fun galleries(argument: List<suspend WorkbookTemplateGalleryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WorkbookTemplateGalleryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.galleries = mapped
    }

    /**
     * @param argument Workbook galleries supported by the template.
     */
    @JvmName("kludrufvykijtcou")
    public suspend fun galleries(
        vararg
        argument: suspend WorkbookTemplateGalleryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            WorkbookTemplateGalleryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.galleries = mapped
    }

    /**
     * @param argument Workbook galleries supported by the template.
     */
    @JvmName("sktigimjxmdjpomi")
    public suspend fun galleries(argument: suspend WorkbookTemplateGalleryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            WorkbookTemplateGalleryArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.galleries = mapped
    }

    /**
     * @param values Workbook galleries supported by the template.
     */
    @JvmName("juynkpybteiuhxrb")
    public suspend fun galleries(vararg values: WorkbookTemplateGalleryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.galleries = mapped
    }

    /**
     * @param value Valid JSON object containing workbook template payload.
     */
    @JvmName("kldhjsnfumsmitnd")
    public suspend fun templateData(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.templateData = mapped
    }

    internal fun build(): WorkbookTemplateLocalizedGalleryArgs = WorkbookTemplateLocalizedGalleryArgs(
        galleries = galleries,
        templateData = templateData,
    )
}
